/*
 * Copyright (c) 2015 - 2016, Freescale Semiconductor, Inc.
 * Copyright 2016-2017 NXP
 *
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 *
 * o Redistributions of source code must retain the above copyright notice, this list
 *   of conditions and the following disclaimer.
 *
 * o Redistributions in binary form must reproduce the above copyright notice, this
 *   list of conditions and the following disclaimer in the documentation and/or
 *   other materials provided with the distribution.
 *
 * o Neither the name of the copyright holder nor the names of its
 *   contributors may be used to endorse or promote products derived from this
 *   software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR
 * ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
 * ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
#include "FXAS21002.h"
#include "FXOS8700.h"  
#include "MPL3115.h" 
#include "mbed.h"

// Initialize Serial port
Serial pc(USBTX, USBRX);

// Initialize pins for I2C communication for sensors. Set jumpers J6,J7 in FRDM-STBC-AGM01 board accordingly.
FXOS8700 accel(PTC2,PTC1);
FXOS8700 mag(PTC2,PTC1);
FXAS21002 gyro(PTC2,PTC1,0x20);
MPL3115 mpl3115(PTC2,PTC1);


    
int main()
{

// Configure Accelerometer FXOS8700, Magnetometer FXOS8700 & Gyroscope FXAS21002
    accel.accel_config();
    mag.mag_config();
//    gyro.gyro_config();
    mpl3115.MPL3115_config();
 
    
    float accel_data[3]; float accel_rms=0.0;
    float mag_data[3];   float mag_rms=0.0;
    int16_t gyro_data[3];  float gyro_rms=0.0;
    float alt_data[3];  float alt_rms=0.0;
    float temp_data[1]; 
    char data_bytes[7];
    printf("Begin Data Acquisition....\r\n\r\n");
    wait(0.5);
    
    while(1)
    {
      accel.acquire_accel_data_g(accel_data);
      accel_rms = sqrt(((accel_data[0]*accel_data[0])+(accel_data[1]*accel_data[1])+(accel_data[2]*accel_data[2]))/3);
      //printf("AccX:%4.2f,AccY:%4.2f,AccZ:%4.2f,\t",accel_data[0],accel_data[1],accel_data[2]);
      printf("%f,%f,%f,",accel_data[0],accel_data[1],accel_data[2]);
      wait(0.01);
      
         
      mag.acquire_mag_data_uT(mag_data);
      //printf("MagX:%4.2f,MagY:%4.2f,MagZ:%4.2f,\t",mag_data[0],mag_data[1],mag_data[2]);
      printf("%f,%f,%f,",mag_data[0],mag_data[1],mag_data[2]);
      mag_rms = sqrt(((mag_data[0]*mag_data[0])+(mag_data[1]*mag_data[1])+(mag_data[2]*mag_data[2]))/3);
      wait(0.01);

     
//      gyro.acquire_gyro_data_dps(gyro_data);
      //printf("GyrX:%d,GyrY:%d,GyrZ:%d,\t",gyro.getX(),gyro.getY(),gyro.getZ());
      printf("%d,%d,%d,",gyro.getX(),gyro.getY(),gyro.getZ());
//      gyro_rms = sqrt(((gyro.getX()*gyro.getX())+(gyro.getY()*gyro.getY())+(gyro.getZ()*gyro.getZ()))/3);
      wait(0.01);
      
      mpl3115.acquire_MPL3115_data_Altitude_in_m(alt_data, temp_data, data_bytes);
//      mpl3115.acquire_MPL3115_data_Altitude_in_m(alt_data);
     // printf("Alt:%2f,\tTemp:%2f",alt_data[0],temp_data[0]);
       printf("%2f,%2f",alt_data[0],temp_data[0]);
     // printf("\nDatabytes:%s\n", data_bytes);
//      printf("Alt:%f",alt_data[0]);
      alt_rms = sqrt(((alt_data[0]*alt_data[0])+(alt_data[1]*alt_data[1])+(alt_data[2]*alt_data[2]))/3);
      wait(0.2);
      
      printf("\n\r");
   
      
     }
      
}